@@ -17,7 +17,7 @@ import nfldb.team
 
 __pdoc__ = {}
 
-api_version = 3
+api_version = 4
 __pdoc__['api_version'] = \
     """
     The schema version that this library corresponds to. When the schema
@@ -108,8 +108,7 @@ def connect(database=None, user=None, password=None, host=None, port=None,
         host, port = conf['host'], conf['port']
 
     conn = psycopg2.connect(database=database, user=user, password=password,
-                            host=host, port=port,
-                            cursor_factory=RealDictCursor)
+                            host=host, port=port)
 
     # Start the migration. Make sure if this is the initial setup that
     # the DB is empty.
@@ -272,12 +271,21 @@ class Tx (object):
         self.__cursor = None
         self.__factory = factory
         if self.__factory is None:
-            self.__factory = self.__conn.cursor_factory
+            self.__factory = RealDictCursor
 
     def __enter__(self):
         self.__cursor = self.__conn.cursor(name=self.__name,
                                            cursor_factory=self.__factory)
-        return self.__cursor
+        c = self.__cursor
+
+        #class _ (object):
+        #    def execute(self, *args, **kwargs):
+        #        c.execute(*args, **kwargs)
+        #        print(c.query)
+
+        #    def __getattr__(self, k):
+        #        return getattr(c, k)
+        return c
 
     def __exit__(self, typ, value, traceback):
         if not self.__cursor.closed:
@@ -732,3 +740,11 @@ def _migrate_3(c):
             (gsis_id ASC, player_id ASC);
         CREATE INDEX pp_in_team ON play_player (team ASC);
     ''')
+
+
+def _migrate_4(c):
+    c.execute('''
+        UPDATE team SET city = 'New York' WHERE team_id IN ('NYG', 'NYJ');
+        UPDATE team SET name = 'Giants' WHERE team_id = 'NYG';
+        UPDATE team SET name = 'Jets' WHERE team_id = 'NYJ';
+    ''')
