@@ -634,6 +634,14 @@ class Query (Condition):
         self._andalso += conds
         return self
 
+    def orelse(self, *conds):
+        """
+        Adds the list of `nfldb.Query` objects in `conds` to this
+        query's list of disjunctive conditions.
+        """
+        self._orelse += conds
+        return self
+
     def game(self, **kw):
         """
         Specify search criteria for an NFL game. The possible fields
@@ -1206,12 +1214,19 @@ class Query (Condition):
                     'player': player}
 
         def ids_player(cur):
-            cur.execute('''
-                SELECT player_id FROM player %s %s
-            ''' % (_prefix_and(where('player')), osql('player')))
-            player = IdSet.empty()
-            for row in cur.fetchall():
-                player.add(row[0])
+            w = (_prefix_and(where('player')) + ' ' + osql('player')).strip()
+            if not w:
+                player = IdSet.full()
+            else:
+                cur.execute('SELECT player_id FROM player %s' % w)
+                player = IdSet.empty()
+                for row in cur.fetchall():
+                    player.add(row[0])
+
+            # Don't filter games/drives/plays/play_players if there is no
+            # filter.
+            if not _pk_play(cur, ids):
+                return {'player': player}
 
             player_pks = pkin(['player_id'], player)
             cur.execute('''
