@@ -1122,7 +1122,7 @@ class PlayPlayer (object):
 
     _sql_fields = _sql_columns + _sql_derived
 
-    __slots__ = _sql_fields + ['_db', '_play', '_player']
+    __slots__ = _sql_fields + ['_db', '_play', '_player', 'fields']
 
     # Document instance variables for derived SQL fields.
     # We hide them from the public interface, but make the doco
@@ -1255,9 +1255,13 @@ class PlayPlayer (object):
         The team that this player belonged to when he recorded the
         statistics in this play.
         """
+        self.fields = set()
+        """The set of non-zero statistical fields set."""
+
         seta = setattr
         for cat in stats:
             seta(self, cat, stats[cat])
+            self.fields.add(cat)
 
     @property
     def play(self):
@@ -1281,6 +1285,36 @@ class PlayPlayer (object):
             self._player = Player.from_id(self._db, self.player_id)
         return self._player
 
+    @property
+    def points(self):
+        """
+        The number of points scored in this player statistic. This
+        accounts for touchdowns, extra points, two point conversions,
+        field goals and safeties.
+        """
+        pvals = [
+            ('defense_frec_tds', 6),
+            ('defense_int_tds', 6),
+            ('defense_misc_tds', 6),
+            ('fumbles_rec_tds', 6),
+            ('kicking_rec_tds', 6),
+            ('kickret_tds', 6),
+            ('passing_tds', 6),
+            ('puntret_tds', 6),
+            ('receiving_tds', 6),
+            ('rushing_tds', 6),
+            ('kicking_xpmade', 1),
+            ('passing_twoptm', 2),
+            ('receiving_twoptm', 2),
+            ('rushing_twoptm', 2),
+            ('kicking_fgm', 3),
+            ('defense_safe', 2),
+        ]
+        for field, pval in pvals:
+            if getattr(self, field, 0) != 0:
+                return pval
+        return 0.0
+
     @property
     def _row(self):
         return _as_row(PlayPlayer._sql_columns, self)
@@ -1611,6 +1645,19 @@ class Play (object):
                     self._play_players.append(pp)
         return self._play_players
 
+    @property
+    def points(self):
+        """
+        Returns the number of points scored in this play. See the
+        documentation for `nfldb.PlayPlayer`.`nfldb.PlayPlayer.points`
+        for details on what is included.
+        """
+        for pp in self.play_players:
+            pts = pp.points
+            if pts != 0:
+                return pts
+        return 0
+
     @property
     def _row(self):
         return _as_row(Play._sql_columns, self)
@@ -1890,6 +1937,9 @@ class Drive (object):
         vals = self._row
         _upsert(cursor, 'drive', vals, vals[0:2])
 
+        if not self._plays:
+            return
+
         # Remove any plays that are stale.
         cursor.execute('''
             DELETE FROM play
@@ -2159,6 +2209,17 @@ class Game (object):
         self.time_updated = time_updated
         """The date and time that this game was last updated."""
 
+    @property
+    def is_playing(self):
+        """
+        Returns `True` is the game is currently being played and
+        `False` otherwise.
+
+        A game is being played if it is not finished and if the current
+        time proceeds the game's start time.
+        """
+        return not self.finished and now() >= self.start_time
+
     @property
     def drives(self):
         """
@@ -2230,6 +2291,9 @@ class Game (object):
         vals = self._row
         _upsert(cursor, 'game', vals, [vals[0]])
 
+        if not self._drives:
+            return
+
         # Remove any drives that are stale.
         cursor.execute('''
             DELETE FROM drive
